@@ -10,24 +10,25 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
-$DATE = '2003/09/20';
+$VERSION = '0.03';
+$DATE = '2004/04/13';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Data_Secs2.pm' => [qw(0.02 2003/09/20), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2003/09/20), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2003/09/20), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2003/09/20), 'generated, replaces 0.01'],
-    'lib/Data/Secs2.pm' => [qw(1.15 2003/09/20), 'revised 1.14'],
-    't/Data/Secs2.d' => [qw(0.01 2003/09/18), 'unchanged'],
-    't/Data/Secs2.pm' => [qw(0.01 2003/09/18), 'unchanged'],
-    't/Data/Secs2.t' => [qw(0.02 2003/09/18), 'unchanged'],
-    'tlib/File/Package.pm' => [qw(1.12 2003/09/20), 'unchanged'],
-    'tlib/File/SmartNL.pm' => [qw(1.12 2003/09/20), 'unchanged'],
-    'tlib/Text/Scrub.pm' => [qw(1.11 2003/09/20), 'unchanged'],
-    'tlib/Test/Tech.pm' => [qw(1.15 2003/09/20), 'revised 1.14'],
+    'lib/Docs/Site_SVD/Data_Secs2.pm' => [qw(0.03 2004/04/13), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2004/04/13), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2004/04/13), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2004/04/13), 'generated, replaces 0.02'],
+    'lib/Data/Secs2.pm' => [qw(1.16 2004/04/13), 'revised 1.15'],
+    't/Data/Secs2.d' => [qw(0.02 2004/04/13), 'revised 0.01'],
+    't/Data/Secs2.pm' => [qw(0.02 2004/04/13), 'revised 0.01'],
+    't/Data/Secs2.t' => [qw(0.03 2004/04/13), 'revised 0.02'],
+    't/Data/File/Package.pm' => [qw(1.15 2004/04/13), 'new'],
+    't/Data/File/SmartNL.pm' => [qw(1.13 2004/04/13), 'new'],
+    't/Data/Text/Scrub.pm' => [qw(1.11 2004/04/13), 'new'],
+    't/Data/Test/Tech.pm' => [qw(1.17 2004/04/13), 'new'],
+    't/Data/Data/SecsPack.pm' => [qw(0.02 2004/04/13), 'new'],
 
 );
 
@@ -54,11 +55,11 @@ use vars qw(%INVENTORY);
 
   File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
 
- Revision: A
+ Revision: B
 
- Version: 0.02
+ Version: 0.03
 
- Date: 2003/09/20
+ Date: 2004/04/13
 
  Prepared for: General Public 
 
@@ -87,7 +88,7 @@ no matter how many nests of arrays and hashes it contains.
 
 =head2 1.3 Document overview.
 
-This document releases Data::Secs2 version 0.02
+This document releases Data::Secs2 version 0.03
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -100,12 +101,14 @@ system file specification.
 
 =head2 3.1 Inventory of materials released.
 
-This document releases the file found
-at the following repository(s):
+This document releases the file 
 
-   http://www.softwarediamonds/packages/Data-Secs2-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Data-Secs2-0.02
+ Data-Secs2-0.03.tar.gz
 
+found at the following repository(s):
+
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
 Restrictions regarding duplication and license provisions
 are as follows:
@@ -172,18 +175,19 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Data_Secs2.pm                              0.02    2003/09/20 revised 0.01
- MANIFEST                                                     0.02    2003/09/20 generated, replaces 0.01
- Makefile.PL                                                  0.02    2003/09/20 generated, replaces 0.01
- README                                                       0.02    2003/09/20 generated, replaces 0.01
- lib/Data/Secs2.pm                                            1.15    2003/09/20 revised 1.14
- t/Data/Secs2.d                                               0.01    2003/09/18 unchanged
- t/Data/Secs2.pm                                              0.01    2003/09/18 unchanged
- t/Data/Secs2.t                                               0.02    2003/09/18 unchanged
- tlib/File/Package.pm                                         1.12    2003/09/20 unchanged
- tlib/File/SmartNL.pm                                         1.12    2003/09/20 unchanged
- tlib/Text/Scrub.pm                                           1.11    2003/09/20 unchanged
- tlib/Test/Tech.pm                                            1.15    2003/09/20 revised 1.14
+ lib/Docs/Site_SVD/Data_Secs2.pm                              0.03    2004/04/13 revised 0.02
+ MANIFEST                                                     0.03    2004/04/13 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2004/04/13 generated, replaces 0.02
+ README                                                       0.03    2004/04/13 generated, replaces 0.02
+ lib/Data/Secs2.pm                                            1.16    2004/04/13 revised 1.15
+ t/Data/Secs2.d                                               0.02    2004/04/13 revised 0.01
+ t/Data/Secs2.pm                                              0.02    2004/04/13 revised 0.01
+ t/Data/Secs2.t                                               0.03    2004/04/13 revised 0.02
+ t/Data/File/Package.pm                                       1.15    2004/04/13 new
+ t/Data/File/SmartNL.pm                                       1.13    2004/04/13 new
+ t/Data/Text/Scrub.pm                                         1.11    2004/04/13 new
+ t/Data/Test/Tech.pm                                          1.17    2004/04/13 new
+ t/Data/Data/SecsPack.pm                                      0.02    2004/04/13 new
 
 
 =head2 3.3 Changes
@@ -207,6 +211,15 @@ Added arrayification of REF and GLOB references.
 Thus, the 'Data::Secs2' module will nest into
 REF and GLOB references.
 
+=item Data-Secs2-0.03
+
+The lastest build of Test::STDmaker expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from tlib to t/Data, the same directory as the test script
+and deleting the test library File::TestPath program module.
+
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -231,22 +244,40 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
-   http://www.softwarediamonds/packages/Data-Secs2-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Data-Secs2-0.02
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
+Right click on 'Data-Secs2-0.03.tar.gz' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip Data-Secs2-0.03.tar.gz
+ tar -xf Data-Secs2-0.03.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 
 =item Prerequistes.
 
- None.
+ 'Data::SecsPack' => '0.01',
 
 
 =item Security, privacy, or safety precautions.
@@ -338,11 +369,11 @@ Plain Old Documentation
 __DATA__
 
 DISTNAME: Data-Secs2^
-VERSION : 0.02^
+VERSION : 0.03^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
-REVISION: A^
+PREVIOUS_RELEASE: 0.02^
+REVISION: B^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: Generic file utilities originally developed to support Test::STDmaker^
@@ -368,13 +399,17 @@ CHANGE2CURRENT:  ^
 AUTO_REVISE: 
 lib/Data/Secs2.pm
 t/Data/Secs2.*
-lib/File/Package.pm => tlib/File/Package.pm
-lib/File/SmartNL.pm => tlib/File/SmartNL.pm
-lib/Text/Scrub.pm => tlib/Text/Scrub.pm
-lib/Test/Tech.pm => tlib/Test/Tech.pm
+lib/File/Package.pm => t/Data/File/Package.pm
+lib/File/SmartNL.pm => t/Data/File/SmartNL.pm
+lib/Text/Scrub.pm => t/Data/Text/Scrub.pm
+lib/Test/Tech.pm => t/Data/Test/Tech.pm
+lib/Data/SecsPack.pm => t/Data/Data/SecsPack.pm
 ^
 
-PREREQ_PM:  ^
+PREREQ_PM:
+'Data::SecsPack' => '0.01',
+^
+README_PODS: lib/Data/Secs2.pm^
 TESTS: t/Data/Secs2.t^
 EXE_FILES:  ^
 
@@ -399,6 +434,15 @@ Added arrayification of REF and GLOB references.
 Thus, the 'Data::Secs2' module will nest into
 REF and GLOB references.
 
+\=item Data-Secs2-0.03
+
+The lastest build of Test::STDmaker expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from tlib to t/Data, the same directory as the test script
+and deleting the test library File::TestPath program module.
+
+
 \=back
 
 ^
@@ -469,16 +513,38 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 INSTALLATION:
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
 ${REPOSITORY}
+
+Right click on '${DIST_FILE}' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ${BASE_DIST_FILE}.tar.${COMPRESS_SUFFIX}
+ tar -xf ${BASE_DIST_FILE}.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
+^
+
+SUPPORT: 603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>
 ^
 
 SUPPORT: 603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>^
